bayespy.inference.vmp.nodes.poisson.PoissonDistribution.compute_cgf_from_parents
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.compute_cgf_from_parents